%[if %("%id=tracking%" == "true")% ]%

/**
 * Cookie plugin
 *
 * Copyright (c) 2006 Klaus Hartl (stilbuero.de)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 */

/**
 * Create a cookie with the given name and value and other optional parameters.
 *
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Set the value of a cookie.
 * @example $.cookie('the_cookie', 'the_value', { expires: 7, path: '/', domain: 'jquery.com', secure: true });
 * @desc Create a cookie with all available options.
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Create a session cookie.
 * @example $.cookie('the_cookie', null);
 * @desc Delete a cookie by passing null as value. Keep in mind that you have to use the same path and domain
 *       used when the cookie was set.
 *
 * @param String name The name of the cookie.
 * @param String value The value of the cookie.
 * @param Object options An object literal containing key/value pairs to provide optional cookie attributes.
 * @option Number|Date expires Either an integer specifying the expiration date from now on in days or a Date object.
 *                             If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
 *                             If set to null or omitted, the cookie will be a session cookie and will not be retained
 *                             when the the browser exits.
 * @option String path The value of the path atribute of the cookie (default: path of page that created the cookie).
 * @option String domain The value of the domain attribute of the cookie (default: domain of page that created the cookie).
 * @option Boolean secure If true, the secure attribute of the cookie will be set and the cookie transmission will
 *                        require a secure protocol (like HTTPS).
 * @type undefined
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */

/**
 * Get the value of a cookie with the given name.
 *
 * @example $.cookie('the_cookie');
 * @desc Get the value of a cookie.
 *
 * @param String name The name of the cookie.
 * @return The value of the cookie.
 * @type String
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */
jQuery.cookie = function(name, value, options) {
	if (typeof value != 'undefined') { // name and value given, set cookie
		options = options || {};
		if (value === null) {
			value = '';
			options.expires = -1;
		}
		var expires = '';
		if (options.expires && (typeof options.expires == 'number' || options.expires.toUTCString)) {
			var date;
			if (typeof options.expires == 'number') {
				date = new Date();
				date.setTime(date.getTime() + (options.expires * 24 * 60 * 60 * 1000));
			} else {
				date = options.expires;
			}
			expires = '; expires=' + date.toUTCString(); // use expires attribute, max-age is not supported by IE
		}
		// CAUTION: Needed to parenthesize options.path and options.domain
		// in the following expressions, otherwise they evaluate to undefined
		// in the packed version for some reason...
		var path = options.path ? '; path=' + (options.path) : '';
		var domain = options.domain ? '; domain=' + (options.domain) : '';
		var secure = options.secure ? '; secure' : '';
		document.cookie = [name, '=', encodeURIComponent(value), expires, path, domain, secure].join('');
	} else { // only name given, get cookie
		var cookieValue = null;
		if (document.cookie && document.cookie != '') {
			var cookies = document.cookie.split(';');
			for (var i = 0; i < cookies.length; i++) {
				var cookie = jQuery.trim(cookies[i]);
				// Does this cookie string begin with the name we want?
				if (cookie.substring(0, name.length + 1) == (name + '=')) {
					cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
					break;
				}
			}
		}
		return cookieValue;
	}
};

$(document).ready(function(){

	// Display Until Dismissed
	if ($.cookie('%id=cookie_id%') != '%id=cookie_value%') {
		$('#%id%').delay(0).fadeIn(300);
		$('#%id%').addClass('floatingContentActive');
	}

	// Set cookie status to '%id=cookie_value%' and hide the FloatingContent stack when the close button is clicked
	$('#floatingTracking%id%, .%id=close_button_class%, .floatingContentClose').click(function () {
		var date = new Date();
		date.setTime(date.getTime() + (%id=cookie_length% * 60 * 1000));
		$.cookie('%id=cookie_id%', '%id=cookie_value%', { expires: date, path: '/' });
		$('#%id%').delay(0).fadeOut(300);
		$('#%id%').removeClass('floatingContentActive');
		%[if %("%id=close_button_reload%" == "true")% ]%location.reload();%[endif]%
	});

	// Reset the cookie whenever a button with a class of 'resetFloatingContent' is clicked
	$('.resetFloatingContent').click(function (e) {
		$.cookie('%id=cookie_id%', null, {path:'/'})
		location.reload();
		e.preventDefault();
	});

});

%[endif]%

%[if %("%id=tracking%" == "false")% ]%
// Close without cookie tracking support
$(document).ready(function() {
	$('#floatingTracking%id%, .%id=close_button_class%, .floatingContentClose').click(function () {
		$('#%id%').delay(0).fadeOut(300);
		$('#%id%').removeClass('floatingContentActive');
	});
});
%[endif]%


$(document).ready(function() {
	$('#%id%').addClass('floatingContent');
});

%[if %("%id=location%"=="bottom")%]%var $atm_objFloatingContent_%id%%[if %("%id=speed%"!="0")%]%, atm_intFloatingContentHeight_%id%, atm_intFloatingContentMargin_%id%, atm_intFloatingContentWindowHeight_%id%, atm_intFloatingLeftPosition_%id%, atm_intFloatingTopPosition_%id%, atm_intFloatingBottomMargin_%id% = %[if %(%("%id=bottomMarginDimension%"=="%")% && %(%id=bottomMargin% > 30)%)%]%30%[else]%%id=bottomMargin%%[endif]%%[endif]%;
%[if %("%id=speed%"!="0")%]%function atm_FloatingContent_%id%(){
    var atm_intScrollAmount = $(document).scrollTop();
	atm_intFloatingContentHeight_%id% = $atm_objFloatingContent_%id%.height();
	atm_intFloatingContentWindowHeight_%id% = $(window).height();

	atm_intFloatingContentMargin_%id% = %[if %("%id=bottomMarginDimension%"=="%")%]%(atm_intFloatingContentWindowHeight_%id% / 100) *%[endif]% atm_intFloatingBottomMargin_%id%;
	atm_intFloatingTopPosition_%id% = parseInt(atm_intScrollAmount + atm_intFloatingContentWindowHeight_%id% - atm_intFloatingContentHeight_%id% - atm_intFloatingContentMargin_%id%);

	if( ($(window).height() < $atm_objFloatingContent_%id%.height()) || (!$atm_objFloatingContent_%id%.is(":visible")) ){
		$atm_objFloatingContent_%id%.css('top', atm_intFloatingContentMargin_%id%);
	}
	else {
		$atm_objFloatingContent_%id%.stop().animate({top: atm_intFloatingTopPosition_%id%}, %id=speed%);
	}
}
%[endif]%

$(document).ready(function() {
	$atm_objFloatingContent_%id% = $('#%id%');
	$atm_objFloatingContent_%id%.appendTo('body');
	%[if %("%id=speed%"!="0")%]%atm_intFloatingContentWidth_%id% = $atm_objFloatingContent_%id%.width();
	atm_intFloatingContentHeight_%id% = $atm_objFloatingContent_%id%.height();
	atm_intFloatingContentWindowWidth_%id% = $(window).width();
	atm_intFloatingContentWindowHeight_%id% = $(window).height();

	atm_intFloatingContentMargin_%id% = %[if %("%id=bottomMarginDimension%"=="%")%]%(atm_intFloatingContentWindowHeight_%id% / 100) *%[endif]% atm_intFloatingBottomMargin_%id%;
	atm_intFloatingTopPosition_%id% = parseInt(atm_intFloatingContentWindowHeight_%id% - atm_intFloatingContentHeight_%id% - atm_intFloatingContentMargin_%id%);
	$atm_objFloatingContent_%id%.css('top', atm_intFloatingTopPosition_%id%);

	$(window).scroll(function() { atm_FloatingContent_%id%(); });
	$(window).resize(function() { atm_FloatingContent_%id%(); });%[endif]%
	$('#%id% a.hideFloatingContent').on("click", function(e) { $atm_objFloatingContent_%id%.remove(); $atm_objFloatingContent_%id% = null; e.preventDefault(); });
});
%[endif]%
%[if %("%id=location%"=="center")%]%var $atm_objFloatingContent_%id%, atm_intFloatingContentWidth_%id%, atm_intFloatingContentHeight_%id%, atm_intFloatingContentMargin_%id%, atm_intFloatingContentWindowWidth_%id%, atm_intFloatingContentWindowHeight_%id%, atm_intFloatingLeftPosition_%id%, atm_intFloatingTopPosition_%id%;

function atm_FloatingContent_%id%(){
    var atm_intScrollAmount = $(document).scrollTop();
    atm_intFloatingContentWidth_%id% = $atm_objFloatingContent_%id%.width();
	atm_intFloatingContentHeight_%id% = $atm_objFloatingContent_%id%.height();
	atm_intFloatingContentWindowWidth_%id% = $(window).width();
	atm_intFloatingContentWindowHeight_%id% = $(window).height();

	atm_intFloatingLeftPosition_%id% = (atm_intFloatingContentWindowWidth_%id% - atm_intFloatingContentWidth_%id%) / 2;
	atm_intFloatingTopPosition_%id% = (parseInt(atm_intScrollAmount) + (atm_intFloatingContentWindowHeight_%id% - atm_intFloatingContentHeight_%id%) / 2);

	if( ($(window).height() < $atm_objFloatingContent_%id%.height()) || (!$atm_objFloatingContent_%id%.is(":visible")) ){
		$atm_objFloatingContent_%id%.css('top', atm_intFloatingContentMargin_%id%);
		$atm_objFloatingContent_%id%.css('left', atm_intFloatingLeftPosition_%id%);
	}
	else {
		$atm_objFloatingContent_%id%.css('left', atm_intFloatingLeftPosition_%id%);
		$atm_objFloatingContent_%id%.stop().animate({top: atm_intFloatingTopPosition_%id%}, %id=speed%);
	}
}

$(document).ready(function() {
	$(window).load(function() {
		$atm_objFloatingContent_%id% = $('#%id%');
		$atm_objFloatingContent_%id%.appendTo('body');
		atm_intFloatingContentWidth_%id% = $atm_objFloatingContent_%id%.width();
		atm_intFloatingContentHeight_%id% = $atm_objFloatingContent_%id%.height();
		atm_intFloatingContentWindowWidth_%id% = $(window).width();
		atm_intFloatingContentWindowHeight_%id% = $(window).height();

		atm_intFloatingLeftPosition_%id% = (atm_intFloatingContentWindowWidth_%id% - atm_intFloatingContentWidth_%id%) / 2;
		atm_intFloatingTopPosition_%id% = (atm_intFloatingContentWindowHeight_%id% - atm_intFloatingContentHeight_%id%) / 2;

		$atm_objFloatingContent_%id%.css('left', atm_intFloatingLeftPosition_%id%);
		$atm_objFloatingContent_%id%.css('top', atm_intFloatingTopPosition_%id%);

		$(window).scroll(function() { atm_FloatingContent_%id%(); });
		$(window).resize(function() { atm_FloatingContent_%id%(); });
		$('#%id% a.hideFloatingContent').on("click", function(e) { $atm_objFloatingContent_%id%.remove(); $atm_objFloatingContent_%id% = null; e.preventDefault(); });
	});
});
%[endif]%

%[if %("%id=location%"=="top")%]%var $atm_objFloatingContent_%id%%[if %("%id=speed%"!="0")%]%, atm_intFloatingContentHeight_%id%, atm_intFloatingContentMargin_%id%, atm_intFloatingContentWindowHeight_%id%, atm_intFloatingLeftPosition_%id%, atm_intFloatingTopPosition_%id%, atm_intFloatingTopMargin_%id% = %[if %(%("%id=topMarginDimension%"=="%")% && %(%id=topMargin% > 30)%)%]%30%[else]%%id=topMargin%%[endif]%%[endif]%;
%[if %("%id=speed%"!="0")%]%function atm_FloatingContent_%id%(){
    var atm_intScrollAmount = $(document).scrollTop();
    atm_intFloatingContentWidth_%id% = $atm_objFloatingContent_%id%.width();
	atm_intFloatingContentHeight_%id% = $atm_objFloatingContent_%id%.height();
	atm_intFloatingContentWindowWidth_%id% = $(window).width();
	atm_intFloatingContentWindowHeight_%id% = $(window).height();

	atm_intFloatingContentMargin_%id% = %[if %("%id=topMarginDimension%"=="%")%]%(atm_intFloatingContentWindowHeight_%id% / 100) *%[endif]% atm_intFloatingTopMargin_%id%;
	atm_intFloatingTopPosition_%id% = parseInt(atm_intScrollAmount + atm_intFloatingContentMargin_%id%);

	if( ($(window).height() < $atm_objFloatingContent_%id%.height()) || (!$atm_objFloatingContent_%id%.is(":visible")) ){
		$atm_objFloatingContent_%id%.css('top', atm_intFloatingContentMargin_%id%);
	}
	else {
		$atm_objFloatingContent_%id%.stop().animate({top: atm_intFloatingTopPosition_%id%}, %id=speed%);
	}
}
%[endif]%

$(document).ready(function() {
	$atm_objFloatingContent_%id% = $('#%id%');
	$atm_objFloatingContent_%id%.appendTo('body');
	%[if %("%id=speed%"!="0")%]%atm_intFloatingContentWidth_%id% = $atm_objFloatingContent_%id%.width();
	atm_intFloatingContentHeight_%id% = $atm_objFloatingContent_%id%.height();
	atm_intFloatingContentWindowWidth_%id% = $(window).width();
	atm_intFloatingContentWindowHeight_%id% = $(window).height();

	atm_intFloatingContentMargin_%id% = %[if %("%id=topMarginDimension%"=="%")%]%(atm_intFloatingContentWindowHeight_%id% / 100) *%[endif]% atm_intFloatingTopMargin_%id%;
	atm_intFloatingTopPosition_%id% = parseInt(atm_intFloatingContentMargin_%id%);
	$atm_objFloatingContent_%id%.css('top', atm_intFloatingTopPosition_%id%);

	$(window).scroll(function() { atm_FloatingContent_%id%(); });
	$(window).resize(function() { atm_FloatingContent_%id%(); });%[endif]%
	$('#%id% a.hideFloatingContent').on("click", function(e) { $atm_objFloatingContent_%id%.remove(); $atm_objFloatingContent_%id% = null; e.preventDefault(); });
});
%[endif]%

/*
============================================================
POLITE REMINDER:
It's unlawful to deliberately try to unlock demo versions of stacks or divulge details to anyone else about unlocking demo's. Please purchase this stack if you want a copy of the stack licensed in your name; with no demo restrictions imposed and access to our free support and automatic updates.
============================================================
*/

$(document).ready(function() {
$('#%id%').append("<h5>Free Demo Stack</h5>This demo is provided for your convenience, to help you conduct a full evaluation of the stack, before committing to a possible purchase. While in demo mode, this stack will be hidden after 1 minute and will not display again until the page is reloaded. Automatic updates have been disabled. You can purchase an unlocked copy of this stack securely from the website. This purchased copy will be licensed in your name and carry no demo restrictions. Content and settings you setup now will be retained upon obtaining a full version of the stack.");
$("#%id%").delay(60000).fadeOut(0);
});
